@@ -28,7 +28,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
+#ifdef WIN32
+#include <windows.h>
+#else
 #include <sys/time.h>
+#endif
 #include <GL/gl.h>
 #include "maverik.h"
 #include "city_macros.h"
@@ -59,24 +63,32 @@ MAV_vector object_pos;
 int bb_pos;
 int num_occluders= 0;
 Candidate candidate;
+#ifndef WIN32
 struct timeval starttime,endtime;
+#endif
 double cull_time, render_time;
 
 void
 initTime (void)
 {
+#ifndef WIN32
   gettimeofday(&starttime, NULL);
+#endif
 }
 
 double
 calcTime (void)
 {
+#ifdef WIN32
+  return 1.0;
+#else
   int elapsedSec, elapsedUSec;
 
   gettimeofday(&endtime, NULL);
   elapsedSec= endtime.tv_sec-starttime.tv_sec;
   elapsedUSec= endtime.tv_usec-starttime.tv_usec;
   return 1000.0*(elapsedSec+elapsedUSec/1.0E+6);
+#endif
 }
 
 static int
