@@ -28,7 +28,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "maverik.h"
-#include "mav_avatar.h"
+#include "mav_escapeavatar.h"
 #include "city_macros.h"
 #include "city_types.h"
 
