@@ -28,6 +28,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
+#ifdef WIN32
+#include <windows.h>
+#endif
 #include <GL/gl.h>
 #include "maverik.h"
 #include "city_macros.h"
