@@ -34,13 +34,13 @@ typedef struct {
   MAV_vector normal;
   int num_verts;
   MAV_vector *verts;
-} Polygon;
+} LC_Polygon;
 
 typedef struct {
   float letter_width;
   int num_polys;
   MAV_BB bb;
-  Polygon *polys;
+  LC_Polygon *polys;
 } Alphabet;
 
 typedef struct {
@@ -57,7 +57,7 @@ int mav_characterBBox(MAV_object *, MAV_BB *);
 
 typedef struct {
   int num_polys;
-  Polygon *polys;
+  LC_Polygon *polys;
   MAV_BB bb;
   MAV_surfaceParams *sp;
   MAV_matrix matrix;
