@@ -27,6 +27,19 @@
 
 /*
   The Distributed Legible City
+
+  Implemented by various people at ZKM (http://www.zkm.de) and 
+  the Advanced Interfaces Group (http://aig.cs.man.ac.uk)
+
+  Primary ZKM author:
+   Andreas Schiffler,
+   ZKM, Lorenzstr. 19, 76135 Karlsruhe, Germany
+   schiffler@zkm.de
+
+  AIG authors:
+   See http://aig.cs.man.ac.uk
+
+
   AIG_UPDATE 2
   
   ZKM Nov 26: Bike-control with autocentering and conf file - added.
