@@ -33,13 +33,13 @@ typedef struct {
   MAV_vector normal;
   int num_verts;
   MAV_vector *verts;
-} Polygon;
+} LC_Polygon;
 
 typedef struct {
   float letter_width;
   int num_polys;
   MAV_BB bb;
-  Polygon *polys;
+  LC_Polygon *polys;
 } Alphabet;
 
 typedef struct {
@@ -65,7 +65,7 @@ typedef struct {
   float max_z;
   MAV_vector center;
   float radius;
-  Polygon *polys;
+  LC_Polygon *polys;
   MAV_BB bb;
   MAV_surfaceParams *sp;
   MAV_matrix matrix;
