@@ -27,6 +27,9 @@
 
 
 #include "lcity.h"
+#ifdef WIN32
+#include <windows.h>
+#endif
 #include <GL/gl.h>
 #include <stdio.h>
 
